@@ -10,7 +10,7 @@
 import os
 import sys
 from pathlib import Path
-
+__version__ = "0.1.1"
 sys.path.append(os.getcwd() + os.path.sep)
 
 results_folder = 'results'
@@ -18,4 +18,3 @@ data_folder = 'data'
 Path(os.getcwd() + os.path.sep + data_folder).mkdir(parents=True, exist_ok=True)
 Path(os.getcwd() + os.path.sep + results_folder).mkdir(parents=True, exist_ok=True)
 
-current_network = None
