@@ -134,7 +134,6 @@ def od_graph_from_matrix(od_matrix: np.ndarray, X, Y):
     od_matrix : float array, centroids x centroids
     X : x_coord array of centroids
     Y : y_coord array of centroids
-    time: time at which demand is to enter the network
 
     Returns
     -------
@@ -145,7 +144,7 @@ def od_graph_from_matrix(od_matrix: np.ndarray, X, Y):
     g = nx.MultiDiGraph()
     nodes = [(u, {'x_coord': p[0], 'y_coord': p[1]}) for u, p in enumerate(zip(X, Y))]
     g.add_nodes_from(nodes)
-    edges = [(u, v, 0, {'flow': od_matrix[u, v]}) for u, v in np.argwhere(od_matrix > 0)]
+    edges = [(u, v, 0, {'flow': od_matrix[u, v]}) for u, v in np.argwhere(od_matrix > 0) if u!= v ]
     g.add_edges_from(edges)
     return g
 
